==> piwigo-2.1.5.tbz: www/piwigo/plugins/LocalFilesEditor/language/nl_NL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokale configuratie';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Talen';
$lang['locfiledit_onglet_plug'] = 'Persoonlijke Plugin';
$lang['locfiledit_cant_save'] = 'Er kan niet naar het gebruikte bestand geschreven worden. Controleer of een directorie "include/" beschrijfbaar is (chmod).';
$lang['locfiledit_newfile'] = 'Bestand bestaat niet en zal worden aangemaakt door de LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Bestand succesvol beschreven.';
$lang['locfiledit_show_default'] = 'Geef het referentie-bestand weer: ';
$lang['locfiledit_save_bak'] = 'Bij het opslaan wordt een backup-bestand aangemaakt.';
$lang['locfiledit_saved_bak'] = 'Backup-bestand aangemaakt (%s)';
$lang['locfiledit_save_file'] = 'opslaan bestand';
$lang['locfiledit_choose_file'] = 'Kies het te wijzigen bestand';
$lang['locfiledit_edit'] = 'Wijzig';
$lang['locfiledit_restore'] = 'Restore het backup-bestand';
$lang['locfiledit_restore_confirm'] = 'Aub bevestigen?
Restore wordt pas effectief bij de volgende keer opslaan.';
$lang['locfiledit_bak_loaded1'] = 'Backup-bestand geladen.';
$lang['locfiledit_bak_loaded2'] = 'U moet het bestand opslaan om te kunnen restoren.';
$lang['locfiledit_syntax_error'] = 'Syntax-fout! Bestand kan niet opgeslagen worden.';
$lang['locfiledit_enable_editarea'] = 'Maak Edit-gebied atief';
$lang['locfiledit_disable_editarea'] = 'Deactiveer Edit-gebied';
$lang['locfiledit_new_tpl'] = 'Maak nieuw bestand aan';
$lang['locfiledit_new_filename'] = 'Bestandsnaam';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Lege pagina';
$lang['locfiledit_parent_directory'] = 'Bovenliggende directorie';
$lang['locfiledit_filename_error'] = 'Niet toegestane teken(s) in bestandsnaam.';
$lang['locfiledit_file_already_exists'] = 'Bestand bestaat reeds.';
$lang['locfiledit_model_error'] = 'U moet een model kiezen.';
$lang['locfiledit_empty_filename'] = 'U moet een bestandsnaam opgeven.';
$lang['locfiledit_webmaster_only'] = 'Alleen webbeheerders kunnen lokale bestanden aanmaken of wijzigen.';

?>

==> piwigo-2.3.3.tbz: www/piwigo/plugins/LocalFilesEditor/language/nl_NL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokale configuratie';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Talen';
$lang['locfiledit_onglet_plug'] = 'Persoonlijke Plugin';
$lang['locfiledit_cant_save'] = 'Er kan niet naar het gebruikte bestand geschreven worden. Controleer of een directorie "local/" beschrijfbaar is (chmod).';
$lang['locfiledit_newfile'] = 'Bestand bestaat niet en zal worden aangemaakt door de LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Bestand succesvol beschreven.';
$lang['locfiledit_show_default'] = 'Geef het referentie-bestand weer: ';
$lang['locfiledit_save_bak'] = 'Bij het opslaan wordt een backup-bestand aangemaakt.';
$lang['locfiledit_saved_bak'] = 'Backup-bestand aangemaakt (%s)';
$lang['locfiledit_save_file'] = 'opslaan bestand';
$lang['locfiledit_choose_file'] = 'Kies het te wijzigen bestand';
$lang['locfiledit_edit'] = 'Wijzig';
$lang['locfiledit_restore'] = 'Restore het backup-bestand';
$lang['locfiledit_restore_confirm'] = 'Aub bevestigen?
Restore wordt pas effectief bij de volgende keer opslaan.';
$lang['locfiledit_bak_loaded1'] = 'Backup-bestand geladen.';
$lang['locfiledit_bak_loaded2'] = 'U moet het bestand opslaan om te kunnen restoren.';
$lang['locfiledit_syntax_error'] = 'Syntax-fout! Bestand kan niet opgeslagen worden.';
$lang['locfiledit_new_tpl'] = 'Maak nieuw bestand aan';
$lang['locfiledit_new_filename'] = 'Bestandsnaam';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Lege pagina';
$lang['locfiledit_parent_directory'] = 'Bovenliggende directorie';
$lang['locfiledit_filename_error'] = 'Niet toegestane teken(s) in bestandsnaam.';
$lang['locfiledit_file_already_exists'] = 'Bestand bestaat reeds.';
$lang['locfiledit_model_error'] = 'U moet een model kiezen.';
$lang['locfiledit_empty_filename'] = 'U moet een bestandsnaam opgeven.';
$lang['locfiledit_webmaster_only'] = 'Alleen webbeheerders kunnen lokale bestanden aanmaken of wijzigen.';
?>
